@@ -1,10 +1,11 @@
 # Encoding: utf-8
 import sys
-from .dispersions import *
+from .dispersions.dispersions import *
+from .dispersions.base_dispersion import *
 from .experiment import Experiment
 from .materials import *
 from .math import *
-from .result import Result
+from .result import Result, ResultList
 from .solver2x2 import Solver2x2
 from .solver4x4 import *
 from .structure import *
